import React, { useEffect, useRef, useState } from "react";
import { Graph, Node } from "@antv/x6";
import { Button, Dropdown, MenuProps, Input } from "antd";

export default ({
  node,
  graph,
  img,
  items,
  headerStyle,
}: {
  node: Node;
  graph: Graph;
  img: string;
  items: MenuProps["items"],
  headerStyle: React.CSSProperties
}) => {
  const {name} = node.getData();
  const [editing, setEditing] = useState(false);

  return (
    <>
      <div
        className="flex items-center justify-between px-8px pt-8px rounded-t-8px"
        style={headerStyle}
      >
        <img src={img} alt="logo" className="w-32px mr-4px" />
        {editing ? (
          <Input
            placeholder="请输入节点名称"
            className="flex-1"
            autoFocus
            onBlur={() => setEditing(false)}
          />
        ) : (
          <span
            className="text-16px color-#383743 flex-1"
            onDoubleClick={() => setEditing(true)}
          >
            { name }
          </span>
        )}
        <Dropdown menu={{ items }} overlayStyle={{ width: 120 }}>
          <Button type="text" icon={<i className="iconfont icon-gengduo" />} />
        </Dropdown>
      </div>

      <div className="content px-8px pb-8px cursor-default">
        <div className="truncate text-12px color-#2029459e my-4px">
          这是描述文本内容这是描述文本内容这是描述文本内容这是描述文本内容
        </div>

        <div className="text-12px color-#999">
          <span className="mr-4px">代码</span>
          <span className="color-#666">START</span>
        </div>

        <div className="text-12px color-#999">
          <span className="mr-4px">关联</span>
          <span className="color-#666">xxx页面+</span>
        </div>

        <div className="text-12px color-#999">
          <span className="mr-4px">动作</span>
          <span className="color-#666">xxx页面+</span>
        </div>
      </div>
    </>
  );
};
